#!/opt/exp/adm/bin/ksh


TOOLS=${TOOLS:-/opt/exp}
export TOOLS


. ./buildlib.sh

if [ -z "$TYPE" ]; then
    . ${TOOLS}/.machtype
    TYPE=`${TOOLS}/adm/bin/machines -fgnutype type==$TYPE|awk '{print $1}`
    TYPE=${TYPE:-bogus}
    export TYPE
fi
if [ "$TYPE" = "bogus" ]; then
    echo CANNOT ZEN \$TYPE.  exiting
    exit 1
fi
echo TYPE is ${TYPE}

TOP=`pwd`
OUT=${TOP}/ins
Hint2Env "-" $TOP $TYPE DIR_SUFFIX
Hint2Env "-" $TOP $TYPE DIR_ROOT

Hint2Env "-" $TOP $TYPE VERSION 
echo VERSION=$VERSION

if [ "$1" = "-install" ]; then
    inst_prefix=${DIR_ROOT}${DIR_SUFFIX}
    inst_exec_prefix=${DIR_ROOT}${DIR_SUFFIX}
else
    inst_prefix=${OUT}/share${DIR_SUFFIX}
    inst_exec_prefix=${OUT}/${TYPE}${DIR_SUFFIX}
fi

#SEVERAL PROGRAMS DEPEND ON USING A GNU ALTRNATIVE TO THE SYSTEM VERSION
# DO NOT CHANGE THE PATH UNLESS YOU ARE SURE YOU KNOW WHAT YOU ARE DOING
#PATH=${TOOLS}/gnu/bin:${TOOLS}/bin:${PATH}:/usr/bin/X11:/usr/openwin/bin:${TOOLS}/ast/bin
# PSF Removed ast/bin 07/06/00 - configure looks for getconf, but the ast
# version doesn't produce the expected output
PATH=${TOOLS}/gnu/bin:${TOOLS}/bin:${PATH}:/usr/bin/X11:/usr/openwin/bin

# Does anyone need /usr/local/bin?  It causes problems on isolaris
echo PSF1 PATH=$PATH
PATH=`splitpath |grep -v /usr/local/bin |formpath`
echo PSF2 PATH=$PATH

# PSF Added /usr/ucblib to make perl happy on solaris
# PSF Removed next two lines 6/16/03 - should not be needed
#LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${TOOLS}/gnu/lib:${TOOLS}/ast/lib:/usr/ucblib
#LD_RUN_PATH=${LD_RUN_PATH}:${TOOLS}/gnu/lib:${TOOLS}/ast/lib

Hint2Env "-" $TOP $TYPE DISPLAY "static.ih.lucent.com:0.0"

export TOP inst_prefix inst_exec_prefix PATH DISPLAY LD_LIBRARY_PATH LD_RUN_PATH

if [ "$1" = "-distclean" ]; then
    rm -rf ${OUT} build built failed clean active-* conf-*
    exit 0
fi

if [ "$1" = "-clean" ]; then
    rm -rf build built failed ${OUT} clean
    exit 0
fi


if [ -s clean ]; then
    echo "Cleaning up our mess"
    rm -rf ${OUT} build built failed clean active-* conf-*
fi
unset OUT

#In case the file clean has been removed, re-create it, for NSBD won't
# do so on its own.
if [ ! -f ${TOP}/clean ]; then
    $TOUCH  ${TOP}/clean
fi

if [ ! -f ${TOP}/hints ]; then
	echo "I need a hints file"
	exit 1;
fi

#rm -rf ${TOP}/build
rm -f ${TOP}/failed
if [ ! -d ${inst_prefix} ]; then
    /bin/mkdir -p ${inst_prefix}
fi
if [ ! -d ${inst_exec_prefix} ]; then
    /bin/mkdir -p ${inst_exec_prefix}
fi
if [ ! -d ${TOP}/build ]; then
    /bin/mkdir -p ${TOP}/build
fi
$TOUCH ${TOP}/failed
$TOUCH ${TOP}/built

Hint2Env "-" $TOP $TYPE GNU_PACKAGES

if [ -z "${GNU_PACKAGES}" ]; then
    echo "No packages to compile.  Aborting"
    exit 1;
fi

Hint2Env "-" $TOP $TYPE startScript

if [ -n "${startScript}" ]; then
     echo $startScript
     eval $startScript
fi

for subdir in ${GNU_PACKAGES}; do
    if grep '^'$subdir'$' ${TOP}/built; then
	echo "$subdir has been compiled already"
    else
        echo "Compiling $subdir"
	date

	#Add special things to path for compiling this program
	Hint2Env $subdir $TOP $TYPE pathPrepend
	Hint2Env $subdir $TOP $TYPE pathAppend
	PATH_SAV=${PATH}
	PATH=${pathPrepend:+"${pathPrepend}:"}${PATH}${pathAppend:+":${pathAppend}"}
	echo "New PATH is $PATH"
	export PATH

        if unarchive $subdir $TOP $TYPE ;then
	    #preconfigure dosen't do anything too dangerous, so we don't check
    	    # its exit status
            preconf $subdir $TOP $TYPE
            if conf $subdir $TOP $TYPE; then
		if mk $subdir $TOP $TYPE $inst_prefix $inst_exec_prefix; then
#                    cd ${TOP} && rm -rf build/${subdir} conf-$subdir
		    if [ ! "$ANSICC" = "true" ]; then
                        echo $subdir >> ${TOP}/built
		    fi
		else
                    echo "Could not compile $subdir" >> $TOP/failed
		fi
	    else
                echo "Could not configure $subdir" >> $TOP/failed
            fi
        else
            echo "Could not unsubdir $subdir" >> $TOP/failed
        fi
	PATH=${PATH_SAV}
	export PATH
	date
	echo "done with $subdir"
    fi
    echo; echo
done

for ign in `grep :${TYPE}:ignore ${TOP}/hints | cut -f4 -d:`; do
    grep -v ${ign} ${TOP}/failed > /tmp/tmp-$$
    cp -f /tmp/tmp-$$ ${TOP}/failed
    rm -f /tmp/tmp-$$
done

Hint2Env "-" $TOP $TYPE postScript
if [ -n "${postScript}" ]; then
    echo "$postScript"
    eval "$postScript"
fi

if [ -s ${TOP}/failed ]; then
    echo
    echo "${TYPE} encountered problems with:"
    cat ${TOP}/failed
    echo
    Hint2Env "-" $TOP $TYPE failScript "xterm -T \"failed - $TYPE - \`hostname\`\""
    if [ -n "${failScript}" ]; then
	echo $failScript
	eval $failScript
	exit 1
    fi
else
    echo "COMPILATION COMPLETED"
    Hint2Env "-" $TOP $TYPE completeScript
    if [ -n "${completeScript}" ]; then
	echo $completeScript
	eval $completeScript
    fi
fi


