#!/opt/exp/adm/bin/ksh

TOOLS=${TOOLS:-/opt/exp}
MAKE=gmake
CUT=$TOOLS/gnu/bin/cut
TOUCH=/bin/touch 

case `uname -sm` in

CYGWIN* )
	MAKE=make
	CUT=cut
	;;
Darwin* )
	MAKE=make
	CUT=cut
	TOUCH=touch
	;;
"Linux s390" )
	MAKE=/usr/bin/make
	CUT=cut
	TOUCH=touch
	;;
esac


Hint2Env () {
    hintfile="${2}/hints"
    arch=$3
    progName=$1
    varName=$4
    defaultVal=$5
   
    if grep "^${progName}:${arch}:${varName}:" $hintfile >/dev/null ; then
	export ${varName}="`grep "^${progName}:${arch}:${varName}:" $hintfile | cut -f4- -d:`"
    elif grep "^:${arch}:${varName}:" $hintfile >/dev/null ; then
	export ${varName}="`grep "^:${arch}:${varName}:" $hintfile | cut -f4- -d:`"
    elif grep "^${progName}::${varName}:" $hintfile >/dev/null ; then
	export $varName="`grep "^${progName}::${varName}:" $hintfile | cut -f4- -d:`"
    elif grep "^::${varName}:" $hintfile >/dev/null ; then
	export $varName="`grep "^::${varName}:" $hintfile | cut -f4- -d:`"
    else
	export $varName="$defaultVal";
    fi
    # PSF 5/21/01 - allow vars to include ${TOP}.
    # wanted to allow all variable expansions, but never could figure
    # out how to support variable that contain quotes
    if eval echo $"$varName" | grep '{TOP}'
    then
	set -x
	echo Translating  $varName
    	eval $varName=\"$(eval echo $"$varName" | sed -e 's%${TOP}%'$TOP%)\"
	set +x
    fi
    eval echo $varName set to $"$varName"

    }
		


unarchive () {
    if [ ! -d ${2}/build/${1} ]; then
	/bin/echo "Removing cached config information"
	rm -f ${2}/conf-${1}
	/bin/echo "Unpacking $1 into ${2}/build/${1}"
	cd ${2}/build
	UNPACK=gzip
	if [ -s ${2}/src/${1}*bz2 ]
	then
		UNPACK=bzip2
	fi
	$UNPACK -dc ${2}/src/${1}* | \
	tar -xf - && \
	if [ -f "${2}/patches/${3}/${1}" ]; then
	    echo "applying system specific patch to ${1}"
	    patch -p0 < ${2}/patches/${3}/${1}
	elif [ "`uname -v`" = "2.1.2" ] && \
	    [ -f "${2}/patches/i370/${1}" ]; then
	    echo "applying uts2 specific patch to ${1}"
	    patch -p0 < ${2}/patches/i370/${1}
	elif [ -f "${2}/patches/${1}" ]; then
	    echo "applying patch to ${1}"
	    patch -p0 < ${2}/patches/${1}
	else
	    true
	fi
	chmod -R u+w ${2}/build/${1}* || true
	chmod -R g+w ${2}/build/${1}* || true
	/bin/mv ${2}/build/${1}-* ${2}/build/${1} || true
    fi
    }

preconf () {
    Hint2Env ${1} ${2} ${3} CC ${ANSICC:-gcc}
    Hint2Env ${1} ${2} ${3} CCFLAGS
    Hint2Env ${1} ${2} ${3} CXX
    echo "We will use $CC / $CXX to compile this package"
    echo "Versions:"
    [ "$CC" != "" ] && $CC --version || true
    [ "$CXX" != "" ] && $CXX --version || true
    

    if echo "$HINTS" |grep gcc >/dev/null ; then
	DEFCFLAGS="-O2 "
	DEFLDFLAGS=""
	DEFCXXFLAGS=$CFLAGS
    else
	DEFCFLAGS="-O"
	DEFLDFLAGS=""
	DEFCXXFLAGS=""
    fi
    Hint2Env ${1} ${2} ${3} CFLAGS "${DEFCFLAGS}"
    Hint2Env ${1} ${2} ${3} LDFLAGS "${DEFLDLAGS}"
    Hint2Env ${1} ${2} ${3} CXXFLAGS "${DEFCFLAGS}"
    Hint2Env ${1} ${2} ${3} CPPFLAGS ""
    Hint2Env ${1} ${2} ${3} LIBS ""
    }


conf () {
    Hint2Env ${1} ${2} ${3} configOptions "--host=${3} --build=${3} --disable-nls"
    Hint2Env ${1} ${2} ${3} configProgram "configure"
    Hint2Env ${1} ${2} ${3} configEnv ""
    Hint2Env ${1} ${2} ${3} configDir "."
    Hint2Env ${1} ${2} ${3} DIR_PREFIX "/opt/exp"
    Hint2Env ${1} ${2} ${3} preConfScript "DEFAULT"

    if [ "${configOptions}" != "skip" ]; then

	echo export CC=\"$CC\" > ${2}/conf-${1}-curr
	echo export CXX=\"$CXX\" > ${2}/conf-${1}-curr
	echo export CFLAGS=\"$CFLAGS\" >> ${2}/conf-${1}-curr
	echo export CPPFLAGS=\"$CPPFLAGS\" >> ${2}/conf-${1}-curr
	echo export LDFLAGS=\"$LDFLAGS\" >> ${2}/conf-${1}-curr
	echo export LIBS=\"$LIBS\" >> ${2}/conf-${1}-curr
	echo export CXXFLAGS=\"$CXXFLAGS\" >> ${2}/conf-${1}-curr
	echo export PATH=\"$PATH\" >> ${2}/conf-${1}-curr
	echo export DIR_PREFIX=\"$DIR_PREFIX\" >> ${2}/conf-${1}-curr
	echo export DIR_SUFFIX=\"$DIR_SUFFIX\" >> ${2}/conf-${1}-curr
	echo export configOptions=\"$configOptions\" >> ${2}/conf-${1}-curr
	echo export configEnv=\"$configEnv\" >> ${2}/conf-${1}-curr
	echo export configDir=\"$configDir\" >> ${2}/conf-${1}-curr
	echo export installOptions=\"$installOptions\" >> ${2}/conf-${1}-curr
	echo export preConfScript=\"$preConfScript\" >> ${2}/conf-${1}-curr

	if [ -f ${2}/conf-${1} ]; then
	    if diff --brief ${2}/conf-${1}-curr ${2}/conf-${1}>/dev/null ; then
		echo "Skipping configuration step"
	        rm ${2}/conf-${1}-curr
	    else
		echo "configuration has changed:"
		diff -u ${2}/conf-${1} ${2}/conf-${1}-curr
		rm ${2}/conf-${1}
	    fi
	fi

	cd ${2}/build/${1}*/${configDir}


        if [  "${preConfScript}" != "DEFAULT" ]; then
	    echo "eval ${preConfScript}"
	    eval "${preConfScript}" || return 1
        fi

	if [ -f ${2}/conf-${1}-curr -o ! -f Makefile ]; then
	    if [ -f config.cache ]; then
	        rm config.cache
	    fi

	    mv -f ${2}/conf-${1}-curr ${2}/conf-${1}

    	    echo "${configEnv} ./${configProgram} --prefix=${DIR_PREFIX}${DIR_SUFFIX} ${configOptions}"
	    eval ${configEnv} ./${configProgram} --prefix=${DIR_PREFIX}${DIR_SUFFIX} ${configOptions} || return 1
	fi
    else
	echo "skipping configuration"
    fi
    }

mk () {
    Hint2Env ${1} ${2} ${3} makeOptions "all"
    Hint2Env ${1} ${2} ${3} installOptions "install"
    Hint2Env ${1} ${2} ${3} installCommand "$MAKE prefix=${4} exec_prefix=${5} SHELL=/bin/sh ${installOptions}"

    cd ${2}/build/${1}*

    Hint2Env ${1} ${2} ${3} preMakeScript "DEFAULT"
    if [  "${preMakeScript}" != "DEFAULT" ]; then
	echo "eval ${preMakeScript}"
	eval "${preMakeScript}" || return 1
    fi

    case "${makeOptions}" in 
    skip ) 
	echo "skipping make step"
	;;
    perl* ) 
	echo In mk: perl section
	echo "${installCommand}"
	eval "${installCommand}" || return 1
	;;
    * )	
	echo In mk: default section
	echo "$MAKE ${makeOptions}"
	# mozilla chokes if we have CC and CFLAGS set in the environment, 
	# not sure why this was put in...
	# CC="$CC" eval $MAKE MAKE=$MAKE SHELL=ksh ${makeOptions} || return 1
	if [ `basename $PWD` = perl ] 
	then
		unset LD_LIBRARY_PATH
	fi
	unset CC; unset CFLAGS;  eval $MAKE MAKE=$MAKE SHELL=ksh ${makeOptions} || return 1
	set +x
	# Darwin File system is caseless, so make install fails if INSTALL
 	# exists
	rm -f install
	echo "${installCommand}"
	eval "${installCommand}" || return 1
    esac

    cd ${2}
    }

if [ ! -z "${1}" ]; then
    hintfile=hints
    if grep "^::${1}:" $hintfile >/dev/null ; then
	HINTS=`grep "^::${1}:" $hintfile | $CUT -f4- -d:`
    else
	HINTS=$2;
    fi
    echo "$HINTS"
fi

